pub struct IStorageCreditsInstance<P, N = Ethereum> {
address: Address,
provider: P,
_network: PhantomData<N>,
}Expand description
A IStorageCredits instance.
Contains type-safe methods for interacting with an on-chain instance of the
IStorageCredits contract located at a given address, using a given
provider P.
If the contract bytecode is available (see the sol!
documentation on how to provide it), the deploy and deploy_builder methods can
be used to deploy a new instance of the contract.
See the module-level documentation for all the available methods.
Fields
address: Addressprovider: P_network: PhantomData<N>Implementations
Sourceimpl<P: Provider<N>, N: Network> IStorageCreditsInstance<P, N>
Instantiation and getters/setters.
impl<P: Provider<N>, N: Network> IStorageCreditsInstance<P, N>
Instantiation and getters/setters.
Sourcepub const fn new(address: Address, __provider: P) -> Self
pub const fn new(address: Address, __provider: P) -> Self
Creates a new wrapper around an on-chain IStorageCredits contract instance.
See the wrapper’s documentation for more details.
Sourcepub fn set_address(&mut self, address: Address)
pub fn set_address(&mut self, address: Address)
Sets the address.
Sourceimpl<P: Clone, N> IStorageCreditsInstance<&P, N>
impl<P: Clone, N> IStorageCreditsInstance<&P, N>
Sourcepub fn with_cloned_provider(self) -> IStorageCreditsInstance<P, N>
pub fn with_cloned_provider(self) -> IStorageCreditsInstance<P, N>
Clones the provider and returns a new instance with the cloned provider.
Sourceimpl<P: Provider<N>, N: Network> IStorageCreditsInstance<P, N>
Function calls.
impl<P: Provider<N>, N: Network> IStorageCreditsInstance<P, N>
Function calls.
Sourcepub fn call_builder<C: SolCall>(&self, call: &C) -> SolCallBuilder<&P, C, N>
pub fn call_builder<C: SolCall>(&self, call: &C) -> SolCallBuilder<&P, C, N>
Creates a new call builder using this contract instance’s provider and address.
Note that the call can be any function call, not just those defined in this contract. Prefer using the other methods for building type-safe contract calls.
Sourcepub fn balanceOf(
&self,
account: Address,
) -> SolCallBuilder<&P, balanceOfCall, N>
pub fn balanceOf( &self, account: Address, ) -> SolCallBuilder<&P, balanceOfCall, N>
Creates a new call builder for the [balanceOf] function.
Sourcepub fn modeOf(&self, account: Address) -> SolCallBuilder<&P, modeOfCall, N>
pub fn modeOf(&self, account: Address) -> SolCallBuilder<&P, modeOfCall, N>
Creates a new call builder for the [modeOf] function.
Sourcepub fn budgetOf(&self, account: Address) -> SolCallBuilder<&P, budgetOfCall, N>
pub fn budgetOf(&self, account: Address) -> SolCallBuilder<&P, budgetOfCall, N>
Creates a new call builder for the [budgetOf] function.
Sourcepub fn setMode(
&self,
newMode: <Mode as SolType>::RustType,
) -> SolCallBuilder<&P, setModeCall, N>
pub fn setMode( &self, newMode: <Mode as SolType>::RustType, ) -> SolCallBuilder<&P, setModeCall, N>
Creates a new call builder for the [setMode] function.
Sourcepub fn setBudget(
&self,
creditBudget: u64,
) -> SolCallBuilder<&P, setBudgetCall, N>
pub fn setBudget( &self, creditBudget: u64, ) -> SolCallBuilder<&P, setBudgetCall, N>
Creates a new call builder for the [setBudget] function.
Sourceimpl<P: Provider<N>, N: Network> IStorageCreditsInstance<P, N>
Event filters.
impl<P: Provider<N>, N: Network> IStorageCreditsInstance<P, N>
Event filters.
Sourcepub fn event_filter<E: SolEvent>(&self) -> Event<&P, E, N>
pub fn event_filter<E: SolEvent>(&self) -> Event<&P, E, N>
Creates a new event filter using this contract instance’s provider and address.
Note that the type can be any event, not just those defined in this contract. Prefer using the other methods for building type-safe event filters.